@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: ArgV.cc,v 1.20 2008/11/27 05:56:06 lav Exp $ */
+/* $Id: ArgV.cc,v 1.22 2010/12/28 11:46:25 lav Exp $ */
 
 #include <config.h>
 
@@ -59,15 +58,17 @@ void ArgV::back()
       ind--;
 }
 
-char *ArgV::Combine(int start) const
+char *ArgV::Combine(int start,int end) const
 {
    xstring res("");
-   if(start>=Count())
+   if(!end)
+      end=Count();
+   if(start>=end)
       return res.borrow();
    for(;;)
    {
       res.append(getarg(start++));
-      if(start>=Count())
+      if(start>=end)
 	 return(res.borrow());
       res.append(' ');
    }
