@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: CmdExec.h,v 1.74 2011/04/29 04:58:27 lav Exp $ */
+/* $Id: CmdExec.h,v 1.76 2011/06/10 09:36:43 lav Exp $ */
 
 #ifndef CMDEXEC_H
 #define CMDEXEC_H
@@ -59,7 +58,7 @@ public:
 
 extern CmdFeeder *lftp_feeder;	 // feeder to use after 'lftp' command
 
-class CmdExec : public SessionJob
+class CmdExec : public SessionJob, public ResClient
 {
 public:
 // current command data
@@ -73,6 +72,7 @@ private:
    Buffer cmd_buf;
    bool partial_cmd;
    int alias_field; // length of expanded alias (and ttl for used_aliases)
+   int failed_exit_code;
 
    TouchedAlias *used_aliases;
    void free_used_aliases();
@@ -174,7 +174,7 @@ public:
 
    bool Idle();	// when we have no command running and command buffer is empty
    int Done();
-   int ExitCode() { return exit_code; }
+   int ExitCode() { return failed_exit_code ? failed_exit_code : exit_code; }
    int Do();
    xstring& FormatStatus(xstring&,int,const char *prefix="\t");
    void ShowRunStatus(const SMTaskRef<StatusLine>& s);
