@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: FileAccess.cc,v 1.166 2010/08/17 05:53:34 lav Exp $ */
+/* $Id: FileAccess.cc,v 1.168 2011/03/25 14:35:41 lav Exp $ */
 
 #include <config.h>
 
@@ -207,11 +206,11 @@ void FileAccess::Close()
    ClearError();
 }
 
-void FileAccess::Rename(const char *f,const char *f1)
+void FileAccess::Open2(const char *f,const char *f1,open_mode o)
 {
    Close();
    file1.set(f1);
-   Open(f,RENAME);
+   Open(f,o);
 
    cache->TreeChanged(this,file);
    cache->FileChanged(this,file);
@@ -862,8 +861,7 @@ FileAccess *FileAccess::Protocol::NewSession(const char *proto)
 
 #ifdef WITH_MODULES
 #define PROTO_PREFIX "proto-"
-   char *mod=(char*)alloca(strlen(PROTO_PREFIX)+strlen(proto)+1);
-   sprintf(mod,"%s%s",PROTO_PREFIX,proto);
+   const char *mod=xstring::cat(PROTO_PREFIX,proto,NULL);
    void *map=module_load(mod,0,0);
    if(map==0)
    {
@@ -948,11 +946,7 @@ void FileAccess::Path::Set(const Path *o)
 void FileAccess::Path::Change(const char *new_path,bool new_is_file,const char *new_path_enc,int new_device_prefix_len)
 {
    if(!new_path && new_path_enc)
-   {
-      char *np=alloca_strdup(new_path_enc);
-      url::decode_string(np);
-      new_path=np;
-   }
+      new_path=url::decode(new_path_enc);
    if(!new_path || !*new_path)
       return;
    const char *bn=basename_ptr(new_path);
@@ -997,12 +991,10 @@ void FileAccess::Path::Change(const char *new_path,bool new_is_file,const char *
 	 if(!path[0])
 	    path.set("~");
       }
-      char *newcwd=string_alloca(xstrlen(path)+xstrlen(new_path)+2);
       if(last_char(path)=='/')
-	 sprintf(newcwd,"%s%s",path.get(),new_path);
+	 new_path=xstring::format("%s%s",path.get(),new_path);
       else
-	 sprintf(newcwd,"%s/%s",path.get(),new_path);
-      new_path=newcwd;
+	 new_path=xstring::format("%s/%s",path.get(),new_path);
    }
    path.set(new_path);
    device_prefix_len=new_device_prefix_len;
@@ -1015,16 +1007,11 @@ void FileAccess::Path::Change(const char *new_path,bool new_is_file,const char *
    // sanity check
    if(url)
    {
-      const char *url_path=url+path_index;
-      if(url_path[0]=='/' && url_path[1]=='~')
-	 url_path++;
-      url_path=url::decode(url_path);
-      int up_len=strlen(url_path);
-      if(up_len>1 && url_path[up_len-1]=='/')
-	 up_len--;
-      if(strncmp(url_path,path,up_len))
+      ParsedURL u(url);
+      u.path.chomp('/');
+      if(!u.path.eq(path))
       {
-	 LogError(0,"(BUG?) URL mismatch %s vs %s, dropping URL\n",url.get(),path.get());
+	 LogError(0,"URL mismatch %s [%s] vs %s, dropping URL\n",url.get(),u.path.get(),path.get());
 	 url.set(0);
       }
    }
