@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2010 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: FileCopy.cc,v 1.157 2010/04/29 11:00:41 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.162 2011/04/22 15:43:11 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -629,7 +628,10 @@ void FileCopy::LogTransfer()
       return;
    if(!transfer_log)
    {
-      int fd=open(dir_file(get_lftp_home(),"transfer_log"),O_WRONLY|O_APPEND|O_CREAT,0600);
+      const char *fname = ResMgr::Query("xfer:log-file", 0);
+      if(!fname || !*fname)
+	 fname = dir_file(get_lftp_home(),"transfer_log");
+      int fd = open(fname,O_WRONLY|O_APPEND|O_CREAT,0600);
       if(fd==-1)
 	 return;
       transfer_log=new Log;
@@ -641,7 +643,8 @@ void FileCopy::LogTransfer()
    long long range_limit=GetRangeLimit();
    if(range_limit==FILE_END)
       range_limit=get->GetPos();
-   transfer_log->Format(0,"%s -> %s %lld-%lld %s\n",src,dst,
+   transfer_log->Format(0,"%s -> %s %lld-%lld %s\n",
+      url::remove_password(src),url::remove_password(dst),
       (long long)GetRangeStart(),range_limit,
       Speedometer::GetStr(GetBytesCount()/GetTimeSpent()).get());
 }
@@ -729,6 +732,7 @@ FileCopyPeer::FileCopyPeer(dir_t m) : IOBuffer(m)
    can_seek0=false;
    date_set=false;
    do_set_date=true;
+   do_verify=true;
    ascii=false;
    range_start=0;
    range_limit=FILE_END;
@@ -834,8 +838,10 @@ int FileCopyPeerFA::Do()
 	    fxp_eof:
 	       // FIXME: set date for real.
 	       date_set=true;
-	       if(!verify)
+	       if(!verify && do_verify)
 		  verify=new FileVerificator(session,file);
+	       else
+		  done=true;
 	       return MOVED;
 	    }
 	    else if(res==FA::IN_PROGRESS)
@@ -1061,8 +1067,9 @@ int FileCopyPeerFA::Get_LL(int len)
 	    if(FAmode==FA::QUOTE_CMD)
 	       FAmode=FA::RETRIEVE;
 
-	    char *loc=alloca_strdup(loc_c);
+	    xstring& loc=xstring::get_tmp(loc_c);
 	    session->Close(); // loc_c is no longer valid.
+	    loc_c=0;
 
 	    ParsedURL u(loc,true);
 
@@ -1096,7 +1103,7 @@ int FileCopyPeerFA::Get_LL(int len)
 		  }
 	       }
 
-	       url::decode_string(loc);
+	       loc.url_decode();
 	       const char *slash=strrchr(file,'/');
 	       if(loc[0]!='/' && slash)
 	       {
@@ -1265,7 +1272,9 @@ FileCopyPeerFA *FileCopyPeerFA::New(const FileAccessRef& s,const char *url,int m
 }
 FileCopyPeer *FileCopyPeerFA::Clone()
 {
-   return new FileCopyPeerFA(session->Clone(),file,FAmode);
+   FileCopyPeerFA *c=new FileCopyPeerFA(session->Clone(),file,FAmode);
+   c->orig_url.set(orig_url);
+   return c;
 }
 
 // FileCopyPeerFDStream
@@ -1427,8 +1436,10 @@ int FileCopyPeerFDStream::Do()
 	    }
 	    if(stream && my_stream && !stream->Done())
 	       return m;
-	    if(!verify)
+	    if(!verify && do_verify)
 	       verify=new FileVerificator(stream);
+	    else
+	       done=true;
 	    return MOVED;
 	 }
 	 if(seek_pos==0)
