@@ -1,11 +1,11 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 2000-2008 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -431,6 +430,7 @@ void Fish::SendMethod()
       {
 	 int bs=0x1000;
 	 real_pos=pos-pos%bs;
+	 // non-standard extension
 	 Send("#RETRP %lld %s\n"
 	      "ls -lLd %s; "
 	      "echo '### 100'; "
@@ -520,7 +520,18 @@ void Fish::SendMethod()
 	   "chmod %04o %s; echo '### 000'\n",chmod_mode,e,chmod_mode,e);
       PushExpect(EXPECT_DEFAULT);
       break;
+   case LINK:
+      Send("#LINK %s %s\n"
+	   "ln %s %s; echo '### 000'\n",e,e1,e,e1);
+      PushExpect(EXPECT_DEFAULT);
+      break;
+   case SYMLINK:
+      Send("#SYMLINK %s %s\n"
+	   "ln -s %s %s; echo '### 000'\n",e,e1,e,e1);
+      PushExpect(EXPECT_DEFAULT);
+      break;
    case QUOTE_CMD:
+      // non-standard extension
       Send("#EXEC %s\n"
 	   "%s; echo '### 200'\n",e,file.get());
       PushExpect(EXPECT_QUOTE);
@@ -628,8 +639,6 @@ int Fish::HandleReplies()
    expect_t e=RespQueue.next();
 
    bool keep_message=false;
-   xstring p;
-
    switch(e)
    {
    case EXPECT_FISH:
@@ -646,7 +655,8 @@ int Fish::HandleReplies()
 	 set_home(home_auto);
       cache->SetDirectory(this, home, true);
       break;
-   case EXPECT_CWD:
+   case EXPECT_CWD: {
+      xstring p;
       PopDirectory(&p);
       if(message==0)
       {
@@ -661,6 +671,7 @@ int Fish::HandleReplies()
       else
 	 SetError(NO_FILE,message);
       break;
+   }
    case EXPECT_RETR_INFO:
       if(message && is_ascii_digit(message[0]) && !strchr(message,':'))
       {
@@ -672,13 +683,13 @@ int Fish::HandleReplies()
 	       *opt_size=entity_size;
 	 }
       }
-      else if(message)
+      else if(message && message[0]!='#')
       {
 	 FileInfo *fi=FileInfo::parse_ls_line(message,"GMT");
 	 if(!fi)
 	 {
 	    SetError(NO_FILE,message);
-	    return MOVED;
+	    break;
 	 }
 	 if(fi->defined&fi->SIZE)
 	 {
@@ -1141,12 +1152,10 @@ int FishDirList::Do()
 
 const char *FishDirList::Status()
 {
-   static char s[256];
    if(ubuf && !ubuf->Eof() && session->IsOpen())
    {
-      sprintf(s,_("Getting file list (%lld) [%s]"),
+      return xstring::format(_("Getting file list (%lld) [%s]"),
 		     (long long)session->GetPos(),session->CurrentStatus());
-      return s;
    }
    return "";
 }
