@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 2009-2011 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: Torrent.cc,v 1.53 2011/06/28 09:36:27 lav Exp $ */
+/* $Id: Torrent.cc,v 1.54 2011/08/01 09:51:51 lav Exp $ */
 
 #include <config.h>
 #include <stdlib.h>
@@ -206,6 +205,9 @@ int Torrent::Done() const
 
 void TorrentTracker::Shutdown()
 {
+   if(Failed()) // don't stop a failed tracker
+      return;
+   // stop if have started or at least processing a start request
    if(started || tracker_reply)
       SendTrackerRequest("stopped");
 }
@@ -419,6 +421,7 @@ int TorrentTracker::HandleTrackerReply()
 
    if(reply->type!=BeNode::BE_DICT) {
       SetError("Reply: wrong reply type, must be DICT");
+      tracker_reply=0;
       return MOVED;
    }
 
@@ -428,6 +431,7 @@ int TorrentTracker::HandleTrackerReply()
 	 SetError(b_failure_reason->str);
       else
 	 SetError("Reply: wrong `failure reason' type, must be STR");
+      tracker_reply=0;
       return MOVED;
    }
 
@@ -1061,21 +1065,23 @@ int FDCache::OpenFile(const char *file,int m,off_t size)
    } while(fd==-1 && (errno==EMFILE || errno==ENFILE) && CloseOne());
    FD new_entry = {fd,errno,now.UnixTime()};
    cache[ci].add(file,new_entry);
-#ifdef HAVE_POSIX_FALLOCATE
    if(fd==-1 || size==0)
       return fd;
+#ifdef HAVE_POSIX_FALLOCATE
    if(ci==O_RDWR) {
       struct stat st;
       // check if it is newly created file, then allocate space
       if(fstat(fd,&st)!=-1 && st.st_size==0)
 	 posix_fallocate(fd,0,size);
    }
-   else if(ci==O_RDONLY) {
-      // validation mode
+#endif//HAVE_POSIX_FALLOCATE
+#ifdef HAVE_POSIX_FADVISE
+   if(ci==O_RDONLY) {
+      // validation mode (when validating, size>0)
       posix_fadvise(fd,0,size,POSIX_FADV_SEQUENTIAL);
       posix_fadvise(fd,0,size,POSIX_FADV_NOREUSE);
    }
-#endif//HAVE_POSIX_FALLOCATE
+#endif//HAVE_POSIX_FADVISE
    return fd;
 }
 
