@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef MVJOB_H
@@ -28,17 +27,27 @@
 
 class mvJob : public SessionJob
 {
-   int	 failed;
+   xstring_c from;
+   xstring to;
+   FA::open_mode m;
+   bool	 remove_target;
+   bool	 failed;
+   bool	 done;
+
 public:
    int	 Do();
-   int	 Done() { return session->IsClosed(); }
+   int	 Done() { return done; }
    int	 ExitCode() { return failed; }
 
-   void	 PrintStatus(int,const char *);
+   xstring& FormatStatus(xstring&,int,const char *);
    void	 ShowRunStatus(const SMTaskRef<StatusLine>&);
    void	 SayFinal();
 
-   mvJob(FileAccess *session,const char *from,const char *to);
+   void	 doOpen() const;
+   const char *cmd() const { return m==FA::RENAME ? "mv" : "ln"; }
+
+   mvJob(FileAccess *session,const char *f,const char *t,FA::open_mode m=FA::RENAME);
+   void RemoveTargetFirst() { remove_target=true; }
 };
 
 #endif // MVJOB_H
