@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 2008-2010 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,19 +14,24 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: network.h,v 1.7 2010/04/29 11:00:43 lav Exp $ */
+/* $Id: network.h,v 1.10 2011/03/25 14:27:14 lav Exp $ */
 
 #ifndef NETWORK_H
 #define NETWORK_H
 
-#include <netinet/in.h>
-#include <sys/types.h>
-#include <sys/socket.h>
 #include <string.h>
+#include "sockets.h"
+#include <sys/types.h>
+#if HAVE_SYS_SOCKET_H
+# include <sys/socket.h>
+#elif HAVE_WS2TCPIP_H
+# include <ws2tcpip.h>
+#endif
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 union sockaddr_u
 {
@@ -58,6 +63,7 @@ union sockaddr_u
    bool is_private() const;
    const xstring& to_string() const;
    operator const char *() const { return to_string(); }
+   bool set_defaults(int af,const char *hostname,int port);
 };
 
 class Networker
@@ -77,12 +83,13 @@ protected:
    static int SocketAccept(int fd,sockaddr_u *u,const char *hostname=0);
    static void SetSocketBuffer(int sock,int socket_buffer);
    static void SetSocketMaxseg(int sock,int socket_maxseg);
-   static void SocketBindStd(int s,int af,const char *hostname);
+   static void SocketBindStd(int s,int af,const char *hostname,int port=0);
    static int SocketCreate(int af,int type,int proto,const char *hostname);
    static void SocketTuneTCP(int s,const char *hostname);
    static int SocketCreateTCP(int af,const char *hostname);
    static int SocketCreateUnbound(int af,int type,int proto,const char *hostname);
    static int SocketCreateUnboundTCP(int af,const char *hostname);
+   static void SocketSinglePF(int sock,int pf);
 };
 
 #endif //NETWORK_H
